@@ -1,5 +1,5 @@
-from datetime import datetime
 from uuid import UUID
+from datetime import datetime
 
 import six
 
@@ -22,10 +22,10 @@ class Field(object):
                 'Property {} is marked as read only!'.format(self.name)
             )
 
-        # handle metadata. If metadata is set use _method to signal
+        # handle metadata. If metadata is set use _overwrite_metadata to signal
         # that the resource should be overwritten.
         if self.name == 'metadata':
-            instance._method = 'PUT'
+            instance._overwrite_metadata = True
             if value is None:
                 raise ValidationError('Not a valid dictionary!')
 
@@ -42,10 +42,7 @@ class Field(object):
     def __get__(self, instance, cls):
         try:
             data = instance._data[self.name]
-            if data and isinstance(self, DateTimeField):
-                return datetime.strptime(data, '%Y-%m-%dT%H:%M:%SZ')
-            else:
-                return data
+            return data
         except (KeyError, AttributeError):
             return None
 
@@ -64,9 +61,10 @@ class CompoundField(Field):
         self.cls = cls
 
     def __get__(self, instance, owner):
-        if instance._data[self.name]:
-            return self.cls(api=instance._api, parent=instance,
-                            **(instance._data[self.name]))
+        data = instance._data[self.name]
+        # empty is used for read only fields, None all for others
+        if data is not empty and data is not None:
+            return self.cls(api=instance._api, _parent=instance, **data)
         else:
             return None
 
@@ -78,9 +76,10 @@ class CompoundListField(Field):
         self.cls = cls
 
     def __get__(self, instance, owner):
-        if instance._data[self.name]:
-            return [self.cls(api=instance._api, **item) for item in
-                    instance._data[self.name]]
+        data = instance._data[self.name]
+        # empty is used for read only fields, None for all others
+        if data is not empty and data is not None:
+            return [self.cls(api=instance._api, **item) for item in data]
         else:
             return []
 
@@ -151,6 +150,16 @@ class DateTimeField(Field):
     def __init__(self, name=None, read_only=True):
         super(DateTimeField, self).__init__(name=name, read_only=read_only)
 
+    def __get__(self, instance, cls):
+        data = super(DateTimeField, self).__get__(instance, cls)
+        if data:
+            format = "%Y-%m-%dT%H:%M:%S"
+            if '.' in data:
+                format += ".%f"
+            if 'Z' in data:
+                format += "Z"
+            return datetime.strptime(data, format)
+
 
 class BooleanField(Field):
     def __init__(self, name=None, read_only=False):
