@@ -7,7 +7,7 @@ from sevenbridges.errors import SbgError, ResourceNotModified
 from sevenbridges.meta.collection import Collection
 from sevenbridges.meta.fields import (
     HrefField, StringField, UuidField, BasicListField,
-    CompoundField)
+    CompoundField, DateTimeField)
 from sevenbridges.meta.resource import Resource
 from sevenbridges.meta.transformer import Transform
 from sevenbridges.models.compound.projects.settings import Settings
@@ -26,8 +26,8 @@ class Project(Resource):
         'create': '/projects',
         'get': '/projects/{id}',
         'delete': '/projects/{id}',
+        'member': '/projects/{id}/members/{username}',
         'members_query': '/projects/{id}/members',
-        'members_get': '/projects/{id}/members/{member}',
         'apps': '/apps',
         'files': '/files',
         'tasks': '/tasks'
@@ -40,36 +40,46 @@ class Project(Resource):
     type = StringField(read_only=False, max_length=2)
     tags = BasicListField(read_only=False)
     settings = CompoundField(Settings, read_only=False)
+    root_folder = StringField(read_only=True)
+    created_by = StringField(read_only=True)
+    created_on = DateTimeField(read_only=True)
+    modified_on = DateTimeField(read_only=True)
 
     def __str__(self):
         return six.text_type('<Project: id={id}>'.format(id=self.id))
 
     def __eq__(self, other):
-        if self is None and other:
+        if not hasattr(other, '__class__'):
             return False
-        if other is None and self:
+        if not self.__class__ == other.__class__:
             return False
-        if self is other:
-            return True
-        return self.id == other.id and self.__class__ == other.__class__
+        return self is other or self.id == other.id
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
 
     @classmethod
-    def query(cls, owner=None, offset=None, limit=None, api=None):
+    def query(cls, owner=None, name=None, offset=None, limit=None, api=None):
         """
         Query (List) projects
         :param owner: Owner username.
+        :param name: Project name
         :param offset: Pagination offset.
         :param limit: Pagination limit.
         :param api: Api instance.
         :return: Collection object.
         """
         api = api if api else cls._API
+        query_params = {}
         if owner:
             url = cls._URL['query'].format(owner=owner)
         else:
             url = cls._URL['query'].format(owner='')
+        if name:
+            query_params['name'] = name
         return super(Project, cls)._query(
-            url=url, offset=offset, limit=limit, fields='_all', api=api
+            url=url, offset=offset, limit=limit, fields='_all',
+            api=api, **query_params
         )
 
     @classmethod
@@ -90,13 +100,13 @@ class Project(Resource):
         if name is None:
             raise SbgError('Project name is required!')
 
-        if billing_group:
-            billing_group = Transform.to_billing_group(billing_group)
-
         data = {
             'name': name,
-            'billing_group': billing_group,
         }
+
+        if billing_group:
+            data['billing_group'] = Transform.to_billing_group(billing_group)
+
         if description:
             data['description'] = description
         if tags:
@@ -181,7 +191,7 @@ class Project(Resource):
                 'data': data,
             }
         }
-        logger.info('Adding member using username', extra=extra)
+        logger.info('Adding member', extra=extra)
         response = self._api.post(
             url=self._URL['members_query'].format(id=self.id), data=data)
         member_data = response.json()
@@ -195,7 +205,7 @@ class Project(Resource):
         :return: Member object.
         """
         team = Transform.to_team(team)
-        data = {'id': team, 'type': 'TEAM'}
+        data = {'username': team, 'type': 'TEAM'}
         if isinstance(permissions, dict):
             data.update({
                 'permissions': permissions
@@ -208,7 +218,7 @@ class Project(Resource):
                 'data': data,
             }
         }
-        logger.info('Adding team member using team id', extra=extra)
+        logger.info('Adding team member', extra=extra)
         response = self._api.post(
             url=self._URL['members_query'].format(id=self.id), data=data)
         member_data = response.json()
@@ -222,7 +232,7 @@ class Project(Resource):
         :return: Member object.
         """
         division = Transform.to_division(division)
-        data = {'id': division, 'type': 'DIVISION'}
+        data = {'username': division, 'type': 'DIVISION'}
         if isinstance(permissions, dict):
             data.update({
                 'permissions': permissions
@@ -235,7 +245,7 @@ class Project(Resource):
                 'data': data,
             }
         }
-        logger.info('Adding team member using division id', extra=extra)
+        logger.info('Adding division member', extra=extra)
         response = self._api.post(
             url=self._URL['members_query'].format(id=self.id), data=data)
         member_data = response.json()
@@ -268,12 +278,27 @@ class Project(Resource):
         member_data = response.json()
         return Member(api=self._api, **member_data)
 
+    def get_member(self, username, api=None):
+        """
+        Fetches information about a single project member
+        :param username: Member name
+        :param api: Api instance
+        :return: Member object
+        """
+        api = api if api else self._API
+
+        response = api.get(
+            url=self._URL['member'].format(id=self.id, username=username),
+        )
+        data = response.json()
+        return Member(api=api, **data)
+
     def remove_member(self, user):
         """
         Remove member from the project.
         :param user: User to be removed.
         """
-        member = Transform.to_user(user)
+        username = Transform.to_user(user)
         extra = {
             'resource': self.__class__.__name__,
             'query': {
@@ -283,7 +308,7 @@ class Project(Resource):
         }
         logger.info('Removing member', extra=extra)
         self._api.delete(
-            url=self._URL['members_get'].format(id=self.id, member=member)
+            url=self._URL['member'].format(id=self.id, username=username)
         )
 
     def get_files(self, offset=None, limit=None):
@@ -354,7 +379,8 @@ class Project(Resource):
 
     def create_task(self, name, app, revision=None, batch_input=None,
                     batch_by=None, inputs=None, description=None, run=False,
-                    disable_batch=False, interruptible=True):
+                    disable_batch=False, interruptible=True,
+                    execution_settings=None):
         """
         Creates a task for this project.
 
@@ -368,11 +394,12 @@ class Project(Resource):
         :param run: True if you want to run a task upon creation.
         :param disable_batch: True if you want to disable batching.
         :param interruptible: True if you want to use interruptible instances.
+        :param execution_settings: Execution settings for the task.
         :return: Task object.
         """
         return self._api.tasks.create(
             name=name, project=self, app=app, revision=revision,
             batch_input=batch_input, batch_by=batch_by, inputs=inputs,
             description=description, run=run, disable_batch=disable_batch,
-            interruptible=interruptible
+            interruptible=interruptible, execution_settings=execution_settings
         )
